.. toctree::
   tutorials/tut_01_extract_spectra
   tutorials/tut_02_redshift
   tutorials/tut_03_plot_spectra
   tutorials/tut_04_plot_anim
   tutorials/tut_05_datacubes
   :caption: Getting Started:
